@@ -12,9 +12,9 @@ import abobjs
 
 class AB_Continous_Monitoring_Monitors(abobjs.AB_Base):
 
-    _endpoint = "/api/v1/continous_monitoring_monitors"
+    _endpoint = "/api/v1/continuous_monitoring_monitors"
     _single = ".continuous_monitoring_monitors[0]"
-    _name = "continous_monitoring_monitors"
+    _name = "continuous_monitoring_monitors"
 
     _uid_field = None
 
